intelmq.bots.parsers.shodan package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.shodan package

## Submodules

## intelmq.bots.parsers.shodan.parser module

Shodan Stream Parser

Copyright (C) 2018 by nic.at GmbH

`intelmq.bots.parsers.shodan.parser.` `BOT`

  alias of `intelmq.bots.parsers.shodan.parser.ShodanParserBot`

class `intelmq.bots.parsers.shodan.parser.` `ShodanParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `apply_mapping`(mapping, data, key_path=())
  `common_keys` = {'_id', '_shodan', 'asn', 'data', 'device', 'devicetype', 'domains', 'hash', 'hostnames', 'html', 'ip', 'ip_str', 'isp', 'location', 'opts', 'org', 'os', 'port', 'tags', 'timestamp', 'transport'}
  `init`()
  `process`()

## Module contents